@@ -4,6 +4,7 @@
 #include <QPixmap>
 #include <QPushButton>
 #include <QTime>
+#include <QString>
 
 
 struct drinkDefinition {
@@ -11,6 +12,7 @@ struct drinkDefinition {
     int percentage;
     QString text;
     QString filename;
+    float price;
 };
 
 struct drink {
@@ -21,6 +23,7 @@ struct drink {
     float additivePermill;
     bool haveToPay;
     bool addsPermill;
+    float bill;
 };
 
 struct settingsStruct {
