@@ -3,6 +3,7 @@
 #include "settings.h"
 #include "diagram.h"
 #include "newdrink.h"
+#include "changeuser.h"
 
 #include <string>
 #include <sstream>
@@ -12,35 +13,43 @@
 #include <QMessageBox>
 #include <QDesktopServices>
 #include <QUrl>
+#include <QPropertyAnimation>
+#include <QSequentialAnimationGroup>
+#include <QAbstractScrollArea>
+#include <QScrollArea>
+#include <QScrollBar>
+
 
 
 using namespace std;
 
-#define button_width 120
-#define button_height 70
-#define button_gap 10
+const int button_width=140;
+const int button_height=70;
+const int button_gap=10;
+const int CALC_INTERVAL=60000; //msecs
 
 #define THE_ANSWER 42
 
+int yOffset=25;
+
 DrinkCounter::DrinkCounter(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::DrinkCounter)
 {
-    QSettings settings("Fssoft", "DrinkCounter");
+    QPixmap *pix;
+    QPixmap *pix2;
+
     ui->setupUi(this);
-    bool firstStart;
 
-    sett.bodyAge = settings.value("bodyAge").toInt();
-    sett.bodyGenderIsFemale = settings.value("bodyGender").toBool();
-    sett.bodyHeight = settings.value("bodyHeight").toInt();
-    sett.bodyWeight = settings.value("bodyWeight").toInt();
-    sett.permillePerHour = settings.value("permillePerHour").toDouble();
-    sett.driveLimit = settings.value("driveLimit").toDouble();
-    ui->actionEnable_drag_drop->setChecked( settings.value("dragNdrop").toBool() );
-    firstStart = settings.value("firstStart").toInt();
+    actualPage=1;
+    hasChanged=false;
 
-    if(firstStart==THE_ANSWER)
-        ui->actionEnable_drag_drop->setChecked(true);
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
+
+    loadProgramSettings();
+    loadPersonalSettings();
 
     alc = new Alcohol(&drinks, &drinkDefs, &timeLine, &sett);
 
@@ -59,9 +68,18 @@ DrinkCounter::DrinkCounter(QWidget *parent) :
     calcTimer = new QTimer(this);
     connect(calcTimer, SIGNAL(timeout()), this, SLOT(calcTimer_timeout()));
 
+    soundTimer = new QTimer(this);
+    connect(soundTimer, SIGNAL(timeout()), this, SLOT(soundTimer_timeout()));
+
     trashTimer = new QTimer(this);
     connect(trashTimer, SIGNAL(timeout()), this, SLOT(trashTimer_timeout()));
 
+    startTimer = new QTimer(this);
+    connect(startTimer, SIGNAL(timeout()), this, SLOT(startTimer_timeout()));
+
+    uiChangeDelayTimer = new QTimer(this);
+    connect(uiChangeDelayTimer, SIGNAL(timeout()), this, SLOT(uiChangeDelay_timeout()));
+
     drinkButtons = new QButtonGroup;
     connect(drinkButtons, SIGNAL(buttonPressed(int)), this, SLOT(btnPressed(int)));
     connect(drinkButtons, SIGNAL(buttonReleased(int)), this, SLOT(btnReleased(int)));
@@ -69,15 +87,36 @@ DrinkCounter::DrinkCounter(QWidget *parent) :
     drinkButtonsDone = new QButtonGroup;
     connect(drinkButtonsDone, SIGNAL(buttonClicked(int)), this, SLOT(btnDoneClicked(int)));
 
+    btnNextPage = new QPushButton(this);
+    btnNextPage->setVisible(false);
+    btnNextPage->setFlat(true);
+    //btnNextPage->setText(">>");
+    pix = new QPixmap(":/images/arrow_right.png");
+    btnNextPage->setIcon(*pix);
+    btnNextPage->setIconSize(QSize(button_height, button_height));
+    delete pix;
+    connect(btnNextPage, SIGNAL(clicked()), this, SLOT(btnNextPage_clicked()));
+
+    btnPrevPage = new QPushButton(this);
+    btnPrevPage->setFlat(true);
+    btnPrevPage->setVisible(false);
+    //btnPrevPage->setText("<<");
+    pix = new QPixmap(":/images/arrow_left.png");
+    btnPrevPage->setIcon(*pix);
+    btnPrevPage->setIconSize(QSize(button_height, button_height));
+    delete pix;
+    connect(btnPrevPage, SIGNAL(clicked()), this, SLOT(btnPrevPage_clicked()));
+
     trashLabel = new QLabel(this);
     editLabel = new QLabel(this);
     trashLabel->setGeometry(this->width(), 10, button_width, button_width);
     editLabel->setGeometry(this->width(), button_width+15, button_width, button_width);
-    QPixmap *pix = new QPixmap(":/images/trash.png");
-    QPixmap *pix2 = new QPixmap(pix->scaledToWidth(button_width, Qt::FastTransformation));
+    pix = new QPixmap(":/images/trash.png");
+    pix2 = new QPixmap(pix->scaledToWidth(button_width, Qt::FastTransformation));
     trashLabel->setPixmap(*pix2);
     delete pix; pix=0;
     delete pix2; pix2=0;
+
     pix = new QPixmap(":/images/edit.png");
     pix2 = new QPixmap(pix->scaledToWidth(button_width, Qt::FastTransformation));
     editLabel->setPixmap(*pix2);
@@ -86,30 +125,18 @@ DrinkCounter::DrinkCounter(QWidget *parent) :
     trashLabel->show();
     editLabel->show();
 
-    loadDefinitions();
-    loadDrinks();
 
-    calcTimer->start(60000);
-    //calcTimer->start(1000);
-    showAlc();
+
+    startTimer->start(500);
 
 }
 
-DrinkCounter::~DrinkCounter()
-{
-    QSettings settings("Fssoft", "DrinkCounter");
-
-    settings.clear();
-
-    settings.setValue("bodyAge", sett.bodyAge);
-    settings.setValue("bodyHeight", sett.bodyHeight);
-    settings.setValue("bodyGender", sett.bodyGenderIsFemale);
-    settings.setValue("bodyWeight", sett.bodyWeight);
-    settings.setValue("permillePerHour", sett.permillePerHour);
-    settings.setValue("driveLimit", sett.driveLimit);
-    settings.setValue("dragNdrop", ui->actionEnable_drag_drop->isChecked());
-    settings.setValue("firstStart", THE_ANSWER);
+DrinkCounter::~DrinkCounter() {
+    clearUserSettings();
+    clearSettings();
 
+    saveProgramSettings();
+    savePersonalSettings();
     saveDrinks();
     saveDefinitions();
 
@@ -140,6 +167,12 @@ void DrinkCounter::changeEvent(QEvent *e)
     }
 }
 
+void DrinkCounter::resizeEvent(QResizeEvent* event) {
+    if(startTimer->isActive())
+        return;
+    uiChangeDelayTimer->start(10);
+}
+
 std::string intToString(int val) {
     std::string str;
     std::ostringstream ss;
@@ -148,15 +181,69 @@ std::string intToString(int val) {
     return str;
 }
 
-void DrinkCounter::setToStartPos(QPushButton *btn, int btnNr, bool animation=false) {
-    const int buttons_in_row=5;
+int DrinkCounter::getMaxDrinksInRow() {
+    int xMax=0;
+    int xPos=0;
+    while(xMax+button_width < ui->btnNewDrink->geometry().x()) {
+        xMax+=(button_width+button_gap);
+        xPos++;
+    }
 
-    if(animation)
-        slideTo(btn, (button_width+button_gap)*(btnNr%buttons_in_row) + button_gap, (btnNr/buttons_in_row)*(button_height + button_gap) + button_gap );
+    if(xPos==0)
+        return 1;
     else
-        btn->setGeometry((button_width+button_gap)*(btnNr%buttons_in_row) + button_gap, (btnNr/buttons_in_row)*(button_height + button_gap) + button_gap, button_width, button_height);
+        return xPos;
+}
 
+int DrinkCounter::getXPos(int btnNr) {
+    return (button_width+button_gap)*(btnNr%getMaxDrinksInRow()) + button_gap;
+}
 
+int DrinkCounter::getYPos(int btnNr) {
+    return (btnNr/getMaxDrinksInRow())*(button_height + button_gap) + button_gap;
+}
+
+int DrinkCounter::getMaxDrinksPerPage() {
+    int yMax=0;
+    int yPos=0;
+    while(yMax+button_height < (ui->boxHistory->geometry().y()+20) ) {
+        yMax+=(button_height+button_gap);
+        yPos++;
+    }
+
+    if(yPos==0)
+        return 1;
+    else
+        return (yPos*getMaxDrinksInRow()-2);
+}
+
+void DrinkCounter::setToStartPos(QPushButton *btn, int btnNr, bool animation=false) {
+    int xPos=getXPos(btnNr-getMaxDrinksPerPage()*(actualPage-1));
+    int yPos=getYPos(btnNr-getMaxDrinksPerPage()*(actualPage-1));
+
+    if(btnNr < getMaxDrinksPerPage()*actualPage && btnNr >= getMaxDrinksPerPage()*(actualPage-1)) {
+        btn->setVisible(true);
+    }
+    else {
+        btn->setVisible(false);
+        return;
+    }
+
+    if(animation) {
+        slideTo(btn, xPos, yPos );
+        btn->setIconSize(QSize(button_width, button_height));
+    }
+    else {
+        btn->setGeometry(xPos, yPos, button_width, button_height);
+        QPropertyAnimation *anim = new QPropertyAnimation(btn, "iconSize");
+        anim->setDuration(500);
+        anim->setEasingCurve(QEasingCurve::InOutQuad);
+        anim->setStartValue(QSize(0, 0));
+        anim->setEndValue(QSize(button_width, button_height));
+        anim->start();
+        runningAnimations.append(anim);
+        //connect(anim, SIGNAL(finished()), this, SLOT(animationCleanup()));
+    }
 
 }
 
@@ -232,11 +319,17 @@ void drawText(QPixmap *pix, QString line1="", QString line2="") {
     painter.end();
 }
 
-void DrinkCounter::addDrink(int btnNr, QTime timeQ, time_t unixTime, bool addsPermill=true, bool haveToPay=true) {
+void DrinkCounter::addDrink(int btnNr, QTime timeQ, time_t unixTime, bool addsPermill=true, bool haveToPay=true, float bill=0) {
     if (btnNr>=drinkDefs.count())
         return;
 
-    QPixmap *pix2 = new QPixmap(drinkDefs.at(btnNr).filename);
+    QPixmap *pix2;
+
+    if(btnNr==-1)
+        pix2 = new QPixmap(":/images/money.png");
+    else
+        pix2 = new QPixmap(drinkDefs.at(btnNr).filename);
+
     QPixmap *pix = new QPixmap(pix2->scaledToWidth(button_width, Qt::FastTransformation));
     drink dr;
     int pos=drinks.count();
@@ -244,11 +337,24 @@ void DrinkCounter::addDrink(int btnNr, QTime timeQ, time_t unixTime, bool addsPe
     dr.type = btnNr;
     dr.time = timeQ;
     dr.unixTime = unixTime;
-    dr.additivePermill = alc->calcAlc(btnNr);
+    if(btnNr==-1) {
+        dr.additivePermill=0;
+        dr.bill=bill;
+    }
+    else {
+        dr.additivePermill = alc->calcAlc(btnNr);
+        dr.bill=0;
+    }
     dr.haveToPay=haveToPay;
     dr.addsPermill=addsPermill;
 
-    QString txt = drinkDefs.at(btnNr).text;
+    QString txt;
+    if(btnNr==-1) {
+        txt = "Bill: " + QString::number(bill);
+    }
+    else
+        txt = drinkDefs.at(btnNr).text;
+
     QString timeStr = dr.time.toString("hh:mm");
 
     drawText(pix, txt, timeStr);
@@ -256,7 +362,8 @@ void DrinkCounter::addDrink(int btnNr, QTime timeQ, time_t unixTime, bool addsPe
     dr.btn = new QPushButton(ui->drinksDone);
 
     dr.btn->setGeometry((button_width+button_gap)*drinks.count(), button_gap, button_width, button_height);
-    dr.btn->setIconSize(QSize(button_width, button_height));
+    //dr.btn->setIconSize(QSize(button_width, button_height));
+    dr.btn->setIconSize(QSize(0, 0));
     dr.btn->setIcon(*pix);
     dr.btn->show();
 
@@ -266,7 +373,15 @@ void DrinkCounter::addDrink(int btnNr, QTime timeQ, time_t unixTime, bool addsPe
 
     drinkButtonsDone->addButton(dr.btn, pos);
 
+    QPropertyAnimation *anim = new QPropertyAnimation(dr.btn, "iconSize");
+    anim->setDuration(1000);
+    anim->setEasingCurve(QEasingCurve::InOutQuad);
+    anim->setStartValue(QSize(0,0));
+    anim->setEndValue(QSize(button_width,button_height));
+    anim->start();
+    runningAnimations.append(anim);
 
+    hasChanged=true;
 
     delete pix;pix=0;
     delete pix2;pix2=0;
@@ -285,13 +400,21 @@ void DrinkCounter::addDef(drinkDefinition def)
     drawText(pix, def.text);
 
     btn->setIcon(*pix);
+    btn->setIconSize(QSize(0, 0));
     setToStartPos(btn, pos);
-    btn->setIconSize(QSize(button_width, button_height));
     btn->setFlat(true);
     btn->show();
 
+    if(drinkDefs.count()/getMaxDrinksPerPage() >=1 && !startTimer->isActive()) {
+        btnNextPage->setVisible(true);
+        btnPrevPage->setVisible(true);
+    }
+
     drinkButtons->addButton(btn, pos);
     drinkDefs.append(def);
+
+    hasChanged=true;
+
     delete pix; pix=0;
     delete pix2;pix2=0;
 }
@@ -300,6 +423,9 @@ void DrinkCounter::deleteDefinition(int btnNr)
 {
     QAbstractButton *but = drinkButtons->button(btnNr);
     QMessageBox msgBox;
+#ifdef Q_WS_MAEMO_5
+    msgBox.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
     msgBox.setWindowTitle("Delete drink");
     msgBox.setText("This will delete you history.\nAre you sure to remove this drink and begin a new history?");
     msgBox.setStandardButtons(QMessageBox::No | QMessageBox::Yes);
@@ -339,19 +465,11 @@ void DrinkCounter::editDefinition(int btnNr) {
     reloadDefinitions();
 }
 
-void DrinkCounter::deleteDrinks()
-{
-    for(int i=0; i<drinks.count(); i++) {
-        delete drinks.at(i).btn;
-    }
-    drinks.clear();
-}
-
 void DrinkCounter::showAlc() {
     alc->calcTimeLine();
     if(alc->getTimeLineCount()<1)
     {
-        ui->btnDiagram->setText("You are\nnot drunken");
+        ui->btnDiagram->setText("0\nper mill");
         return;
     }
 
@@ -362,12 +480,24 @@ void DrinkCounter::showAlc() {
 
 }
 
+void DrinkCounter::animationCleanup() {
+    for(int i=0; i<runningAnimations.size(); i++) {
+        if((*runningAnimations.at(i)).state() == QPropertyAnimation::Stopped) {
+            //disconnect(runningAnimations.at(i));
+            delete runningAnimations[i];
+            runningAnimations[i]=0;
+            runningAnimations.remove(i);
+        }
+    }
+}
+
+
 
 //##### Timers
 
 void DrinkCounter::dragNdropTimer_timeout() {
     posX = QCursor::pos().x() - this->geometry().x();// - ui->wdgDrinks->geometry().x() - ui->sarDrinks->geometry().x();
-    posY = QCursor::pos().y() - this->geometry().y() - 5;// - ui->wdgDrinks->geometry().y() - ui->sarDrinks->geometry().y();
+    posY = QCursor::pos().y() - this->geometry().y() - yOffset;// - ui->wdgDrinks->geometry().y() - ui->sarDrinks->geometry().y();
 
     drinkButtons->button(activeButton)->setGeometry(posX-button_width/2, posY-button_height/2, button_width, button_height);
 }
@@ -399,6 +529,8 @@ void DrinkCounter::dropDelayTimer_timeout()
         trashTimer->start();
         dropDelayTimer->stop();
         timeouts=0;
+        //if(yOffset<50)
+        //    yOffset+=10;
         showAlc();
     }
     else
@@ -407,7 +539,18 @@ void DrinkCounter::dropDelayTimer_timeout()
 }
 
 void DrinkCounter::calcTimer_timeout() {
+    if(hasChanged) {
+        clearUserSettings();
+        clearSettings();
+        saveProgramSettings();
+        savePersonalSettings();
+        saveDrinks();
+        saveDefinitions();
+        hasChanged=false;
+    }
     showAlc();
+    calcTimer->setInterval(CALC_INTERVAL);
+    animationCleanup();
 }
 
 void DrinkCounter::trashTimer_timeout()
@@ -423,13 +566,18 @@ void DrinkCounter::trashTimer_timeout()
         else {
             trashLabel->setGeometry(trashLabel->x()-step, trashLabel->y(), trashLabel->width(), trashLabel->height());
             editLabel->setGeometry(editLabel->x()-step, editLabel->y(), editLabel->width(), editLabel->height());
+            trashLabel->show();
+            editLabel->show();
         }
 
     }
     else
     {
-        if(trashLabel->x() > this->width())
+        if(trashLabel->x() > this->width()) {
             trashTimer->stop();
+            trashLabel->hide();
+            editLabel->hide();
+        }
         else {
             trashLabel->setGeometry(trashLabel->x()+step, trashLabel->y(), trashLabel->width(), trashLabel->height());
             editLabel->setGeometry(editLabel->x()+step, editLabel->y(), editLabel->width(), editLabel->height());
@@ -452,6 +600,30 @@ void DrinkCounter::slideTimer_timeout() {
         }
 }
 
+void DrinkCounter::startTimer_timeout() {
+    loadDefinitions();
+    loadDrinks();
+
+    calcTimer->start(CALC_INTERVAL);
+    showAlc();
+    uiChangeDelayTimer->start(1);
+
+    startTimer->stop();
+}
+
+void DrinkCounter::soundTimer_timeout() {
+    //music->pause();
+    soundTimer->stop();
+}
+
+void DrinkCounter::uiChangeDelay_timeout() {
+    reloadDefinitions();
+
+    btnNextPage->setGeometry(getXPos(getMaxDrinksPerPage()+1), getYPos(getMaxDrinksPerPage()+1)+20, button_width, button_height);
+    btnPrevPage->setGeometry(getXPos(getMaxDrinksPerPage()), getYPos(getMaxDrinksPerPage())+20, button_width, button_height);
+
+    uiChangeDelayTimer->stop();
+}
 
 // ##### Button slots
 
@@ -466,37 +638,22 @@ void DrinkCounter::on_btnDiagram_clicked() {
     dia->show();
 }
 
-void DrinkCounter::on_btnNewParty_clicked() {
-    QMessageBox msgBox;
-    msgBox.setWindowTitle("New Party?");
-    msgBox.setText("Are you sure to begin a new history?");
-    msgBox.setStandardButtons(QMessageBox::No | QMessageBox::Yes);
-    msgBox.setDefaultButton(QMessageBox::No);
-    int ret = msgBox.exec();
-
-    switch (ret) {
-        case QMessageBox::Yes:
-            deleteDrinks();
-            break;
-        case QMessageBox::No:
-
-            break;
-    }
-
-}
-
 void DrinkCounter::on_actionSettings_triggered()
 {
     settings *set = new settings(this, sett);
     set->exec();
     sett = set->sett;
     delete set;set=0;
-    showAlc();
+    calcTimer->stop();
+    calcTimer->start(1000);
 }
 
 void DrinkCounter::on_actionAbout_triggered()
 {
     QMessageBox msgBox;
+#ifdef Q_WS_MAEMO_5
+    msgBox.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
     QString str;
     const QUrl url("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=FC8VEACGJFN9J&lc=AT&item_name=Andreas%20Weidlinger&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted");
 
@@ -526,6 +683,48 @@ void DrinkCounter::on_actionAbout_triggered()
     }
 }
 
+void DrinkCounter::on_actionDelete_History_triggered() {
+    QMessageBox msgBox;
+#ifdef Q_WS_MAEMO_5
+    msgBox.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
+    msgBox.setWindowTitle("New Party?");
+    msgBox.setText("Are you sure to begin a new history?");
+    msgBox.setStandardButtons(QMessageBox::No | QMessageBox::Yes);
+    msgBox.setDefaultButton(QMessageBox::No);
+    int ret = msgBox.exec();
+
+    switch (ret) {
+        case QMessageBox::Yes:
+            deleteDrinks();
+            calcTimer->stop();
+            calcTimer->start(500);
+            break;
+        case QMessageBox::No:
+
+            break;
+    }
+
+}
+
+void DrinkCounter::on_btnMakeBill_clicked()
+{
+    Bill *bill = new Bill(this, &drinks, &drinkDefs);
+    #ifdef Q_WS_MAEMO_5
+        bill->setAttribute(Qt::WA_Maemo5StackedWindow);
+        //bill->setWindowFlags(bill->windowFlags() | Qt::Window);
+    #endif
+
+    bill->exec();
+
+    if(bill->isAccepted())
+    {
+        addDrink(-1, QTime::currentTime(), time(NULL), false, false, bill->getSum());
+    }
+    delete bill; bill=0;
+
+}
+
 void DrinkCounter::on_btnNewDrink_clicked()
 {
     NewDrink *dr = new NewDrink();
@@ -557,39 +756,67 @@ void DrinkCounter::btnReleased(int btnNr) {
         activeButton = btnNr;
         dropDelayTimer->start(50);
     }
-    else
+    else {
         addDrink(btnNr, QTime::currentTime(), time(NULL));
+    }
 
     showAlc();
 
-    ui->scrollArea->ensureVisible(ui->drinksDone->width(),0,0,0);//scroll max to the right side
+    //ui->scrollArea->ensureVisible(ui->drinksDone->width(),0,0,0);//scroll max to the right side
+
+    //ui->scrollArea->horizontalScrollBar()->setRange(0, ui->drinksDone->minimumWidth()/2);
+
+    QPropertyAnimation *anim = new QPropertyAnimation(ui->scrollArea->horizontalScrollBar(), "value");
+    anim->setDuration(1000);
+    anim->setEasingCurve(QEasingCurve::InOutQuad);
+    anim->setStartValue(ui->scrollArea->horizontalScrollBar()->value());
+    anim->setEndValue(ui->drinksDone->minimumWidth());
+    anim->start();
+    runningAnimations.append(anim);
 }
 
 void DrinkCounter::btnDoneClicked(int btnNr)
 {
     QMessageBox msgBox;
+#ifdef Q_WS_MAEMO_5
+    msgBox.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
     QString str;
     drink dr;
     dr = drinks.at(btnNr);
+    bool bill=false;
+
+    if( drinks.at(btnNr).type == -1 )
+        bill=true;
+
+    if(bill) {
+        str="Do you want to delete this bill?";
+    }
+    else {
+        str="What do you want to do with this drink?";
+    }
+
 
-    str="What do you want to do with this drink?";
     msgBox.addButton("Delete", QMessageBox::YesRole);
 
-    if(!drinks.at(btnNr).addsPermill)
-    {
-        str+="\n-> Another person have drunken it";
-        msgBox.addButton("I have drunk it", QMessageBox::ApplyRole);
-    }
-    else
-        msgBox.addButton("Another person drank it", QMessageBox::ApplyRole);
+    if(!bill) {
+        if(!drinks.at(btnNr).addsPermill)
+        {
+            str+="\n-> Another person have drunken it";
+            msgBox.addButton("I have drunk it", QMessageBox::ApplyRole);
+        }
+        else
+            msgBox.addButton("Another person drank it", QMessageBox::ApplyRole);
 
-    if(!drinks.at(btnNr).haveToPay)
-    {
-        str+="\n-> You dont have to pay for that drink";
-        msgBox.addButton("I have to pay for it", QMessageBox::AcceptRole);
+        if(!drinks.at(btnNr).haveToPay)
+        {
+            str+="\n-> You dont have to pay for that drink";
+            msgBox.addButton("I have to pay for it", QMessageBox::AcceptRole);
+        }
+        else
+            msgBox.addButton("I dont have to pay for it", QMessageBox::AcceptRole);
     }
-    else
-        msgBox.addButton("I dont have to pay for it", QMessageBox::AcceptRole);
+
 
     msgBox.addButton("Abort", QMessageBox::NoRole);
 
@@ -605,6 +832,8 @@ void DrinkCounter::btnDoneClicked(int btnNr)
             for(int i=btnNr+1; i<drinks.count()+1; i++)
                 drinkButtonsDone->setId(drinkButtonsDone->button(i), i-1);
             reloadDrinks();
+            calcTimer->stop();
+            calcTimer->start(500);
             break;
 
         case 1:
@@ -624,43 +853,32 @@ void DrinkCounter::btnDoneClicked(int btnNr)
     }
 }
 
+void DrinkCounter::btnNextPage_clicked() {
+    if(actualPage <= drinkDefs.count()/getMaxDrinksPerPage()) {
+        actualPage++;
+        reloadDefinitions();
+    }
+    animationCleanup();
+}
+
+void DrinkCounter::btnPrevPage_clicked() {
+    if(actualPage>1) {
+        actualPage--;
+        reloadDefinitions();
+    }
+    animationCleanup();
+}
 
 //##### fileops
 
 void DrinkCounter::loadDrinks() {
-/*    QString fname = QCoreApplication::applicationDirPath() + "/drinks.txt";
-    string line;
-    QString lineQ;
-    ifstream in(fname.toStdString().c_str());
-
     int drinkType, hour, min;
     time_t unixTime;
     QTime time;
     bool addsPermill, haveToPay;
+    float bill;
 
-    drinks.clear();
-
-    while (getline(in, line)) {
-        if(line.length()<3) break;
-        lineQ = line.c_str();
-        drinkType = lineQ.section(';', 0,0).toInt();
-        hour = lineQ.section(';', 1,1).toInt();
-        min = lineQ.section(';', 2,2).toInt();
-        unixTime = lineQ.section(';', 3,3).toUInt();
-        addsPermill = (bool)lineQ.section(';', 4,4).toInt();
-        haveToPay = (bool)lineQ.section(';', 5,5).toInt();
-
-        time.setHMS(hour, min, 0, 0);
-
-        addDrink(drinkType, time, unixTime, addsPermill, haveToPay);
-    }*/
-
-    int drinkType, hour, min;
-    time_t unixTime;
-    QTime time;
-    bool addsPermill, haveToPay;
-
-    QSettings settings("Fssoft", "DrinkCounter");
+    QSettings settings("Fssoft", "DrinkCounter" + currentUser);
     int size = settings.beginReadArray("drinks");
     for (int i = 0; i < size; ++i) {
         settings.setArrayIndex(i);
@@ -670,21 +888,16 @@ void DrinkCounter::loadDrinks() {
         unixTime = settings.value("unixTime").toUInt();
         addsPermill = settings.value("addsPermill").toBool();
         haveToPay = settings.value("haveToPay").toBool();
+        bill = settings.value("bill").toFloat();
 
         time.setHMS(hour, min, 0, 0);
-        addDrink(drinkType, time, unixTime, addsPermill, haveToPay);
+        addDrink(drinkType, time, unixTime, addsPermill, haveToPay, bill);
     }
     settings.endArray();
 }
 
 void DrinkCounter::saveDrinks() {
-/*    QString fname = QCoreApplication::applicationDirPath() + "/drinks.txt";
-    ofstream out(fname.toStdString().c_str());
-    for(int i=0; i<drinks.count(); i++) {
-        out << drinks.at(i).type << ";" << drinks.at(i).time.toString("hh;mm").toStdString() << ";" << drinks.at(i).unixTime << ";" << drinks.at(i).addsPermill << ";" << drinks.at(i).haveToPay << endl;
-    }*/
-
-    QSettings settings("Fssoft", "DrinkCounter");
+    QSettings settings("Fssoft", "DrinkCounter" + currentUser);
     settings.beginWriteArray("drinks");
     for (int i = 0; i < drinks.size(); ++i) {
         settings.setArrayIndex(i);
@@ -694,55 +907,28 @@ void DrinkCounter::saveDrinks() {
         settings.setValue("unixTime", (unsigned int)drinks.at(i).unixTime);
         settings.setValue("addsPermill", drinks.at(i).addsPermill);
         settings.setValue("haveToPay", drinks.at(i).haveToPay);
+        settings.setValue("bill", drinks.at(i).bill);
 
     }
     settings.endArray();
 }
 
-void DrinkCounter::reloadDrinks()
-{
-    saveDrinks();
+void DrinkCounter::deleteDrinks() {
     for(int i=0; i<drinks.count(); i++)
     {
         delete drinks.at(i).btn;
     }
     drinks.clear();
+}
+
+void DrinkCounter::reloadDrinks()
+{
+    saveDrinks();
+    deleteDrinks();
     loadDrinks();
 }
 
 void DrinkCounter::loadDefinitions() {
-    /*int i=0;
-    string line;
-    QString lineQ;
-    ifstream in("drinkDB.txt");
-
-    while (getline(in, line)) {
-        drinkDefinition drDef;
-
-        lineQ = line.c_str();
-        drDef.text = lineQ.section(';', 0,0);
-        drDef.amountMl = lineQ.section(';', 1,1).toInt();
-        drDef.percentage = lineQ.section(';', 2,2).toInt();
-        drDef.filename = lineQ.section(';', 3,3);
-
-
-        QPushButton *btn = new QPushButton(this);
-        //QPushButton *btn = new QPushButton(ui->wdgDrinks);
-        QPixmap *pix = new QPixmap(drDef.filename);
-
-        drawText(pix, drDef.text);
-
-        btn->setIcon(*pix);
-        setToStartPos(btn, i);
-        btn->setIconSize(QSize(button_width, button_height));
-        btn->setFlat(true);
-        btn->show();
-
-        drinkButtons->addButton(btn, i);
-        drinkDefs.append(drDef);
-        delete pix; pix=0;
-        i++;
-    }*/
     QSettings settings("Fssoft", "DrinkCounter");
     int size = settings.beginReadArray("drinkDefs");
     for (int i = 0; i < size; ++i) {
@@ -752,6 +938,7 @@ void DrinkCounter::loadDefinitions() {
         def.filename = settings.value("filename").toString();
         def.percentage = settings.value("percentage").toInt();
         def.text = settings.value("text").toString();
+        def.price = settings.value("price").toFloat();
 
         addDef(def);
     }
@@ -767,6 +954,7 @@ void DrinkCounter::saveDefinitions() {
         settings.setValue("filename", drinkDefs.at(i).filename);
         settings.setValue("percentage", drinkDefs.at(i).percentage);
         settings.setValue("text", drinkDefs.at(i).text);
+        settings.setValue("price", drinkDefs.at(i).price);
     }
     settings.endArray();
 }
@@ -796,4 +984,97 @@ void DrinkCounter::reloadDefinitions()
     //loadDefinitions();
 }
 
+void DrinkCounter::savePersonalSettings() {
+    QSettings settings("Fssoft", "DrinkCounter" + currentUser);
 
+    settings.setValue("bodyAge", sett.bodyAge);
+    settings.setValue("bodyHeight", sett.bodyHeight);
+    settings.setValue("bodyGender", sett.bodyGenderIsFemale);
+    settings.setValue("bodyWeight", sett.bodyWeight);
+    settings.setValue("permillePerHour", sett.permillePerHour);
+    settings.setValue("driveLimit", sett.driveLimit);
+}
+
+void DrinkCounter::loadPersonalSettings() {
+    QSettings settings("Fssoft", "DrinkCounter" + currentUser);
+
+    sett.bodyAge = settings.value("bodyAge").toInt();
+    sett.bodyGenderIsFemale = settings.value("bodyGender").toBool();
+    sett.bodyHeight = settings.value("bodyHeight").toInt();
+    sett.bodyWeight = settings.value("bodyWeight").toInt();
+    sett.permillePerHour = settings.value("permillePerHour").toDouble();
+    sett.driveLimit = settings.value("driveLimit").toDouble();
+
+}
+
+void DrinkCounter::loadProgramSettings() {
+    QSettings settings("Fssoft", "DrinkCounter" + currentUser);
+    int firstStart;
+
+    currentUser = settings.value("currentUser").toString();
+    ui->actionEnable_drag_drop->setChecked( settings.value("dragNdrop").toBool() );
+    firstStart = settings.value("firstStart").toInt();
+
+    if(firstStart!=THE_ANSWER)
+        ui->actionEnable_drag_drop->setChecked(true);
+}
+
+void DrinkCounter::saveProgramSettings() {
+    QSettings settings("Fssoft", "DrinkCounter");
+    settings.setValue("dragNdrop", ui->actionEnable_drag_drop->isChecked());
+    settings.setValue("firstStart", THE_ANSWER);
+    settings.setValue("currentUser", currentUser);
+}
+
+void DrinkCounter::clearSettings() {
+    QSettings settings("Fssoft", "DrinkCounter");
+    settings.clear();
+}
+
+void DrinkCounter::clearUserSettings() {
+    QSettings settings("Fssoft", "DrinkCounter" + currentUser);
+    settings.clear();
+}
+
+void DrinkCounter::on_actionChange_user_triggered()
+{
+    QString newUser=currentUser;
+    ChangeUser *change = new ChangeUser(this, &newUser);
+    #ifdef Q_WS_MAEMO_5
+        change->setAttribute(Qt::WA_Maemo5StackedWindow);
+    #endif
+
+
+    change->exec();
+
+    checkEasterEgg(newUser);
+
+    if(change->isAccepted)
+    {
+        if(newUser!=currentUser) {
+            clearUserSettings();
+            saveDrinks();
+            savePersonalSettings();
+
+            currentUser = newUser;
+
+            loadPersonalSettings();
+            deleteDrinks();
+            loadDrinks();
+        }
+
+    }
+    delete change; change=0;
+}
+
+
+
+void DrinkCounter::checkEasterEgg(QString str) {
+/*    if(str=="elli") {
+        static bool first = true;
+        if(first)
+            music = Phonon::createPlayer(Phonon::MusicCategory, Phonon::MediaSource("/home/user/sound.mp3"));
+        music->play();
+        soundTimer->start(20000);
+    }*/
+}
